@@ -99,7 +99,7 @@ class SvnWikiView(object):
         #    return exc.HTTPForbidden('WTH?')
 
         message = request.POST.get('svenweb.commit_message')
-        kind = request.POST.get('svenweb.mimetype')
+        mimetype = request.POST.get('svenweb.mimetype')
 
         if request.GET.has_key('factory'):
             title = request.GET.get('factory')
@@ -107,19 +107,19 @@ class SvnWikiView(object):
                 import random
                 title = random.randint(0, 1000000)
             uri = '/'.join((request.path_info, str(title)))
-            self.svn(request).write(uri, contents, message, kind)
+            self.svn(request).write(uri, contents, message, mimetype)
             return exc.HTTPSeeOther(location=request.path_info)
 
         try:
-            self.svn(request).write(request.path_info, contents, message, kind)
+            self.svn(request).write(request.path_info, contents, message, mimetype)
         except NotAFile:
-            if kind:
-                self.svn(request).set_kind(request.path_info, kind, message)
+            if mimetype:
+                self.svn(request).set_mimetype(request.path_info, mimetype, message)
             else:
                 import random
                 title = random.randint(0, 1000000)
                 uri = '/'.join((request.path_info, str(title)))
-                self.svn(request).write(uri, contents, message, kind)
+                self.svn(request).write(uri, contents, message, mimetype)
                 #return exc.HTTPBadRequest("Cannot edit directories")
 
         return exc.HTTPSeeOther(location=request.path_info)
@@ -133,7 +133,7 @@ class SvnWikiView(object):
             contents = self.svn(request).read(request.path_info)
         except NotAFile: #return exc.HTTPBadRequest("Cannot edit directories")
             return self.get_response("<form method='post'><input type='text' name='svenweb.resource_kind' value='%s'></input><input type='submit' value='Submit'></input></form>" %
-                                     self.svn(request).kind(request.path_info),
+                                     self.svn(request).mimetype(request.path_info),
                                      "text/html")
         except NoSuchResource:
             # this is not great
@@ -145,11 +145,11 @@ class SvnWikiView(object):
             # end(notgreat)
             
             contents = {'body':'',
-                        'mimetype':self.svn(request).kind(parent),
+                        'mimetype':'text/html',
                         }        
 
-        contents['mimetype'] = self.svn(request).kind(request.path_info)
-        kind = contents.get('mimetype')
+        contents['mimetype'] = self.svn(request).mimetype(request.path_info)
+        mimetype = contents.get('mimetype')
         
         # put the raw form of the resource in the wsgi environment
         request.environ['svenweb.resource'] = dict(contents)
